@@ -1,3 +1,3 @@
 from rp_generator.settings.app_settings import *
 from rp_generator.settings.flask_settings import *
-from rp_generator.settings.get_yaml_config import RP_CONFIG
+from rp_generator.settings.get_yaml_config import RP_CONFIG, PATH_TO_RP_CONFIG
